==> ruby-1.9.0-1.zip: ruby-1.9.0-1/transdb.h <==
rb_declare_transcoder("ISO-8859-8", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-1", "single_byte");
rb_declare_transcoder("ISO-2022-JP", "UTF-8", "japanese");
rb_declare_transcoder("UTF-8", "SHIFT_JIS", "japanese");
rb_declare_transcoder("Windows-31J", "UTF-8", "japanese");
rb_declare_transcoder("ISO-8859-7", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-2", "single_byte");
rb_declare_transcoder("UTF-8", "ASCII-8BIT", "single_byte");
rb_declare_transcoder("EUC-KR", "UTF-8", "korean");
rb_declare_transcoder("UTF-8", "EUC-JP", "japanese");
rb_declare_transcoder("UTF-8", "UTF-32BE", "utf_16_32");
rb_declare_transcoder("ISO-8859-14", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-10", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-3", "single_byte");
rb_declare_transcoder("UTF-8", "EUC-KR", "korean");
rb_declare_transcoder("UTF-8", "UTF-32LE", "utf_16_32");
rb_declare_transcoder("ISO-8859-13", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-11", "single_byte");
rb_declare_transcoder("ISO-8859-9", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-4", "single_byte");
rb_declare_transcoder("UTF-8", "US-ASCII", "single_byte");
rb_declare_transcoder("UTF-32LE", "UTF-8", "utf_16_32");
rb_declare_transcoder("UTF-8", "ISO-8859-5", "single_byte");
rb_declare_transcoder("ISO-8859-4", "UTF-8", "single_byte");
rb_declare_transcoder("US-ASCII", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-2022-JP", "japanese");
rb_declare_transcoder("UTF-8", "Windows-31J", "japanese");
rb_declare_transcoder("SHIFT_JIS", "UTF-8", "japanese");
rb_declare_transcoder("UTF-32BE", "UTF-8", "utf_16_32");
rb_declare_transcoder("UTF-8", "ISO-8859-13", "single_byte");
rb_declare_transcoder("ISO-8859-11", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-6", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-14", "single_byte");
rb_declare_transcoder("ISO-8859-10", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-7", "single_byte");
rb_declare_transcoder("ISO-8859-6", "UTF-8", "single_byte");
rb_declare_transcoder("ASCII-8BIT", "UTF-8", "single_byte");
rb_declare_transcoder("EUC-JP", "UTF-8", "japanese");
rb_declare_transcoder("UTF-8", "ISO-8859-15", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-8", "single_byte");
rb_declare_transcoder("ISO-8859-5", "UTF-8", "single_byte");
rb_declare_transcoder("ISO-8859-1", "UTF-8", "single_byte");
rb_declare_transcoder("ISO-8859-15", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-9", "single_byte");
rb_declare_transcoder("UTF-8", "CP949", "korean");
rb_declare_transcoder("UTF-8", "UTF-16LE", "utf_16_32");
rb_declare_transcoder("UTF-16LE", "UTF-8", "utf_16_32");
rb_declare_transcoder("UTF-8", "UTF-16BE", "utf_16_32");
rb_declare_transcoder("UTF-16BE", "UTF-8", "utf_16_32");
rb_declare_transcoder("ISO-8859-3", "UTF-8", "single_byte");
rb_declare_transcoder("ISO-8859-2", "UTF-8", "single_byte");
rb_declare_transcoder("CP949", "UTF-8", "korean");

==> ruby-1.9.0-4.zip: ruby-1.9.0-4/transdb.h <==
rb_declare_transcoder("ISO-8859-14", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-10", "single_byte");
rb_declare_transcoder("ISO-8859-8", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-3", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-11", "single_byte");
rb_declare_transcoder("ISO-8859-9", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-4", "single_byte");
rb_declare_transcoder("UTF-8", "ASCII-8BIT", "single_byte");
rb_declare_transcoder("UTF-8", "EUC-JP", "japanese");
rb_declare_transcoder("UTF-8", "UTF-32BE", "utf_16_32");
rb_declare_transcoder("UTF-8", "ISO-8859-5", "single_byte");
rb_declare_transcoder("", "cr_newline", "newline");
rb_declare_transcoder("UTF-8", "EUC-KR", "korean");
rb_declare_transcoder("Windows-31J", "UTF-8", "japanese");
rb_declare_transcoder("ISO-2022-JP", "EUC-JP", "iso2022");
rb_declare_transcoder("UTF-8", "UTF-32LE", "utf_16_32");
rb_declare_transcoder("UTF-8", "ISO-8859-13", "single_byte");
rb_declare_transcoder("ISO-8859-13", "UTF-8", "single_byte");
rb_declare_transcoder("ISO-8859-11", "UTF-8", "single_byte");
rb_declare_transcoder("ISO-8859-7", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-6", "single_byte");
rb_declare_transcoder("UTF-8", "US-ASCII", "single_byte");
rb_declare_transcoder("EUC-KR", "UTF-8", "korean");
rb_declare_transcoder("UTF-8", "ISO-8859-14", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-7", "single_byte");
rb_declare_transcoder("ISO-8859-6", "UTF-8", "single_byte");
rb_declare_transcoder("US-ASCII", "UTF-8", "single_byte");
rb_declare_transcoder("EUC-JP", "UTF-8", "japanese");
rb_declare_transcoder("UTF-8", "Windows-31J", "japanese");
rb_declare_transcoder("UTF-8", "Shift_JIS", "japanese");
rb_declare_transcoder("Shift_JIS", "UTF-8", "japanese");
rb_declare_transcoder("UTF-8", "ISO-8859-15", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-8", "single_byte");
rb_declare_transcoder("UTF-32LE", "UTF-8", "utf_16_32");
rb_declare_transcoder("ISO-8859-10", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-9", "single_byte");
rb_declare_transcoder("ISO-8859-4", "UTF-8", "single_byte");
rb_declare_transcoder("ASCII-8BIT", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "CP51932", "japanese");
rb_declare_transcoder("UTF-32BE", "UTF-8", "utf_16_32");
rb_declare_transcoder("UTF-8", "UTF-16LE", "utf_16_32");
rb_declare_transcoder("UTF-8", "UTF-16BE", "utf_16_32");
rb_declare_transcoder("ISO-8859-5", "UTF-8", "single_byte");
rb_declare_transcoder("ISO-8859-3", "UTF-8", "single_byte");
rb_declare_transcoder("ISO-8859-1", "UTF-8", "single_byte");
rb_declare_transcoder("", "crlf_newline", "newline");
rb_declare_transcoder("UTF-8", "CP949", "korean");
rb_declare_transcoder("CP51932", "UTF-8", "japanese");
rb_declare_transcoder("EUC-JP", "ISO-2022-JP", "iso2022");
rb_declare_transcoder("UTF-16LE", "UTF-8", "utf_16_32");
rb_declare_transcoder("UTF-16BE", "UTF-8", "utf_16_32");
rb_declare_transcoder("UTF-8", "ISO-8859-1", "single_byte");
rb_declare_transcoder("universal_newline", "", "newline");
rb_declare_transcoder("ISO-8859-15", "UTF-8", "single_byte");
rb_declare_transcoder("UTF-8", "ISO-8859-2", "single_byte");
rb_declare_transcoder("ISO-8859-2", "UTF-8", "single_byte");
rb_declare_transcoder("CP949", "UTF-8", "korean");
